# Session API

!!! info "Overview"
    The `Session` API is the core of canfar, enabling you to create, manage, and destroy sessions on the CANFAR Science Platform.

::: canfar.session.Session
    handler: python
    selection:
      members:
        - fetch
        - create
        - info
        - logs
        - destroy
    rendering:
      members_order: source
      show_root_heading: true
      show_source: true
      heading_level: 2
